@@ -1,8 +1,8 @@
 from .op import OP
-from .opio import OPIO, Artifact, BigParameter, OPIOSign, Parameter
+from .opio import OPIO, Artifact, BigParameter, OPIOSign, Parameter, NestedDict
 from .python_op_template import (FatalError, PythonOPTemplate, Slices,
                                  TransientError, upload_packages)
 
 __all__ = ["OP", "OPIO", "Artifact", "BigParameter", "OPIOSign", "Parameter",
            "FatalError", "PythonOPTemplate", "Slices", "TransientError",
-           "upload_packages"]
+           "upload_packages", "NestedDict"]
